"""Contains function that can be tested."""


def product(a: int, b: int) -> int:
    """Multipy two integers.

    Parameters
    ----------
    a
        multiplier
    b
        multiplicand

    Returns
    -------
    prod
        product

    """
    return a * b
